@@ -16,7 +16,7 @@ use crate::error::TelnetError;
 
 #[derive(Debug, Default)]
 pub struct TelnetBuilder {
-    prompt: String,
+    prompts: Vec<String>,
     username_prompt: String,
     password_prompt: String,
     connect_timeout: Duration,
@@ -25,8 +25,15 @@ pub struct TelnetBuilder {
 
 impl TelnetBuilder {
     /// Set the telnet server prompt, as many characters as possible.(`~` or `#` is not good. May misjudge).
-    pub fn prompt(mut self, prompt: &str) -> TelnetBuilder {
-        self.prompt = prompt.to_string();
+    pub fn prompt<T: ToString>(mut self, prompt: T) -> TelnetBuilder {
+        self.prompts = vec![prompt.to_string()];
+        self
+    }
+
+    /// Set the telnet server prompts, as many characters as possible.(`~` or `#` is not good. May misjudge).
+    /// If `prompts` is set, `prompt` will be overwritten.
+    pub fn prompts<T: ToString>(mut self, prompts: &[T]) -> TelnetBuilder {
+        self.prompts = prompts.iter().map(|p| p.to_string()).collect();
         self
     }
 
@@ -56,7 +63,7 @@ impl TelnetBuilder {
                 content: vec![],
                 stream: res?,
                 timeout: self.timeout,
-                prompt: self.prompt,
+                prompts: self.prompts,
                 username_prompt: self.username_prompt,
                 password_prompt: self.password_prompt,
             }),
@@ -72,7 +79,7 @@ pub struct Telnet {
     timeout: Duration,
     content: Vec<String>,
     stream: TcpStream,
-    prompt: String,
+    prompts: Vec<String>,
     username_prompt: String,
     password_prompt: String,
 }
@@ -99,7 +106,7 @@ impl Telnet {
     ///     .prompt("username@hostname:$ ")
     ///     .login_prompt("login: ", "Password: ")
     ///     .connect_timeout(Duration::from_secs(3))
-    ///     .connect("192.168.0.1").await?;
+    ///     .connect("192.168.0.1:23").await?;
     ///
     /// match client.login("username", "password").await {
     ///     Ok(_) => println!("login success."),
@@ -127,28 +134,34 @@ impl Telnet {
                                     // set window size
                                     if i == 0x1f {
                                         write
-                                            .write(&[
+                                            .write_all(&[
                                                 0xff, 0xfb, 0x1f, 0xff, 0xfa, 0x1f, 0x00, 0xfc,
                                                 0x00, 0x1b, 0xff, 0xf0,
                                             ])
                                             .await?;
                                     } else {
-                                        write.write(&[0xff, 0xfc, i]).await?;
+                                        write.write_all(&[0xff, 0xfc, i]).await?;
                                     }
                                 }
                                 Item::Will(i) | Item::Wont(i) => {
-                                    write.write(&[0xff, 0xfe, i]).await?;
+                                    write.write_all(&[0xff, 0xfe, i]).await?;
                                 }
                                 Item::Line(content) => {
                                     if content.ends_with(self.username_prompt.as_bytes()) {
                                         if auth_failed {
                                             return Err(TelnetError::AuthenticationFailed);
                                         }
-                                        write.write(user.as_bytes()).await?;
+                                        write.write_all(user.as_bytes()).await?;
                                     } else if content.ends_with(self.password_prompt.as_bytes()) {
-                                        write.write(pass.as_bytes()).await?;
+                                        write.write_all(pass.as_bytes()).await?;
                                         auth_failed = true;
-                                    } else if content.ends_with(self.prompt.as_bytes()) {
+                                    } else if self
+                                        .prompts
+                                        .iter()
+                                        .filter(|p| content.ends_with(p.as_bytes()))
+                                        .count()
+                                        != 0
+                                    {
                                         return Ok(());
                                     }
                                 }
@@ -190,7 +203,13 @@ impl Telnet {
                     Some(item) => {
                         if let Item::Line(mut line) = item? {
                             // ignore prompt line
-                            if line.ends_with(self.prompt.as_bytes()) {
+                            if self
+                                .prompts
+                                .iter()
+                                .filter(|p| line.ends_with(p.as_bytes()))
+                                .count()
+                                != 0
+                            {
                                 break;
                             }
                             // ignore command line echo
@@ -213,7 +232,13 @@ impl Telnet {
                                 continue;
                             }
                             // ignore command line
-                            if incomplete_line.ends_with(self.prompt.as_bytes()) {
+                            if self
+                                .prompts
+                                .iter()
+                                .filter(|p| incomplete_line.ends_with(p.as_bytes()))
+                                .count()
+                                != 0
+                            {
                                 break;
                             }
                             if incomplete_line.ends_with(&[10]) {
@@ -260,7 +285,13 @@ impl Telnet {
                 Ok(res) => match res {
                     Some(item) => {
                         if let Item::Line(mut line) = item? {
-                            if line.ends_with(self.prompt.as_bytes()) {
+                            if self
+                                .prompts
+                                .iter()
+                                .filter(|p| line.ends_with(p.as_bytes()))
+                                .count()
+                                != 0
+                            {
                                 break;
                             }
 
@@ -271,7 +302,13 @@ impl Telnet {
                                 continue;
                             }
                             // ignore command line
-                            if incomplete_line.ends_with(self.prompt.as_bytes()) {
+                            if self
+                                .prompts
+                                .iter()
+                                .filter(|p| incomplete_line.ends_with(p.as_bytes()))
+                                .count()
+                                != 0
+                            {
                                 break;
                             }
                             if incomplete_line.ends_with(&[10]) {
